@@ -158,11 +158,7 @@ local void digest_make_crc_table()
 #define DO8 DO1; DO1; DO1; DO1; DO1; DO1; DO1; DO1
 
 /* ========================================================================= */
-unsigned long ZEXPORT digest_crc32(crc, buf, len)
-    unsigned long crc;
-    const unsigned char FAR *buf;
-    unsigned len;
-{
+unsigned long ZEXPORT digest_crc32(unsigned long crc, const unsigned char FAR *buf, unsigned len) {
     if (buf == Z_NULL) return 0UL;
 
 #ifdef DYNAMIC_CRC_TABLE
@@ -201,11 +197,7 @@ unsigned long ZEXPORT digest_crc32(crc, buf, len)
 #define DOLIT32 DOLIT4; DOLIT4; DOLIT4; DOLIT4; DOLIT4; DOLIT4; DOLIT4; DOLIT4
 
 /* ========================================================================= */
-local unsigned long digest_crc32_little(crc, buf, len)
-    unsigned long crc;
-    const unsigned char FAR *buf;
-    unsigned len;
-{
+local unsigned long digest_crc32_little(unsigned long crc, const unsigned char FAR *buf, unsigned len) {
     register u4 c;
     register const u4 FAR *buf4;
 
@@ -241,11 +233,7 @@ local unsigned long digest_crc32_little(crc, buf, len)
 #define DOBIG32 DOBIG4; DOBIG4; DOBIG4; DOBIG4; DOBIG4; DOBIG4; DOBIG4; DOBIG4
 
 /* ========================================================================= */
-local unsigned long digest_crc32_big(crc, buf, len) /* #nocov start */
-    unsigned long crc;
-    const unsigned char FAR *buf;
-    unsigned len;
-{
+local unsigned long digest_crc32_big(unsigned long crc, const unsigned char FAR *buf, unsigned len) {  /* #nocov start */
     register u4 c;
     register const u4 FAR *buf4;
 
